@@ -3,20 +3,21 @@ from stream import exceptions
 import logging
 from stream.signing import sign
 from stream.utils import validate_feed
+import os
 
 logger = logging.getLogger(__name__)
 
 
 class StreamClient(object):
     base_url = 'https://getstream.io/api/'
-    # base_url = 'http://localhost:8000/api/'
 
-    def __init__(self, api_key, api_secret):
+    def __init__(self, api_key, api_secret, base_url=None):
         '''
         Initialize the client with the given api key and secret
 
         :param api_key: the api key
         :param api_secret: the api secret
+        :param base_url: (optionally overwrite the api base url)
 
         **Example usage**::
 
@@ -37,6 +38,10 @@ class StreamClient(object):
         '''
         self.api_key = api_key
         self.api_secret = api_secret
+        if base_url is not None:
+            self.base_url = base_url
+        if os.environ.get('LOCAL'):
+            self.base_url = 'http://localhost:8000/api/'
 
     def feed(self, feed_id):
         '''
@@ -74,16 +79,16 @@ class StreamClient(object):
         headers = self.get_headers(feed)
         url = self.base_url + relative_url
 
-        logger.debug('stream api call %s, headers %s params %s data %s',
-                     url, headers, default_params, data)
         response = method(url, data=data, headers=headers,
                           params=default_params)
+        logger.debug('stream api call %s, headers %s data %s',
+                     response.url, headers, data)
         result = response.json()
         if result.get('exception'):
-            self.raise_exception(result)
+            self.raise_exception(result, status_code=response.status_code)
         return result
 
-    def raise_exception(self, result):
+    def raise_exception(self, result, status_code):
         '''
         Map the exception code to an exception class and raise it
         '''
@@ -93,7 +98,7 @@ class StreamClient(object):
         exception_dict = get_exception_dict()
         exception_class = exception_dict.get(
             error_code, exceptions.StreamApiException)
-        exception = exception_class(error_message)
+        exception = exception_class(error_message, status_code=status_code)
         raise exception
 
     def post(self, *args, **kwargs):
