@@ -3,19 +3,31 @@ import stream
 import time
 from stream.exceptions import ApiKeyException, InputException,\
     CustomFieldException
+import random
+
+
+def connect_debug():
+    return stream.connect(
+        u'5crf3bhfzesn',
+        u'tfq2sdqpj9g446sbv653x3aqmgn33hsn8uzdc9jpskaw8mj6vsnhzswuwptuj9su'
+    )
+
+client = connect_debug()
+user1 = client.feed('user:1')
+aggregated2 = client.feed('aggregated:2')
+aggregated3 = client.feed('aggregated:3')
+flat3 = client.feed('flat:3')
 
 
 class ClientTest(TestCase):
 
     def setUp(self):
         # DEBUG account details
-        self.c = stream.connect(
-            '5crf3bhfzesn',
-            'tfq2sdqpj9g446sbv653x3aqmgn33hsn8uzdc9jpskaw8mj6vsnhzswuwptuj9su'
-        )
-        self.user1 = self.c.feed('user:1')
-        self.aggregated2 = self.c.feed('aggregated:2')
-        self.flat3 = self.c.feed('flat:3')
+        self.c = client
+        self.user1 = user1
+        self.aggregated2 = aggregated2
+        self.aggregated3 = aggregated3
+        self.flat3 = flat3
 
     def test_add_activity(self):
         activity_data = {'actor': 1, 'verb': 'tweet', 'object': 1}
@@ -32,10 +44,11 @@ class ClientTest(TestCase):
         self.assertNotEqual(activities[0]['id'], activity_id)
 
     def test_follow(self):
-        activity_data = {'actor': 1, 'verb': 'tweet', 'object': 1}
+        actor_id = random.randint(10, 100000)
+        activity_data = {'actor': actor_id, 'verb': 'tweet', 'object': 1}
         activity_id = self.user1.add_activity(activity_data)['id']
         self.aggregated2.follow('user:1')
-        time.sleep(10)
+        time.sleep(5)
         activities = self.aggregated2.get(limit=3)['results']
         activity = self._get_first_aggregated_activity(activities)
         activity_id_found = activity['id'] if activity is not None else None
@@ -54,22 +67,22 @@ class ClientTest(TestCase):
     def _get_first_aggregated_activity(self, activities):
         try:
             return activities[0]['activities'][0]
-        except IndexError, e:
+        except IndexError as e:
             pass
 
     def _get_first_activity(self, activities):
         try:
             return activities[0]
-        except IndexError, e:
+        except IndexError as e:
             pass
 
     def test_unfollow(self):
         activity_data = {'actor': 1, 'verb': 'tweet', 'object': 1}
         activity_id = self.user1.add_activity(activity_data)['id']
-        self.aggregated2.follow('user:1')
-        self.aggregated2.unfollow('user:1')
+        self.aggregated3.follow('user:1')
+        self.aggregated3.unfollow('user:1')
         time.sleep(5)
-        activities = self.aggregated2.get(limit=3)['results']
+        activities = self.aggregated3.get(limit=3)['results']
         activity = self._get_first_aggregated_activity(activities)
         activity_id_found = activity['id'] if activity is not None else None
         self.assertNotEqual(activity_id_found, activity_id)
